summaryrefslogtreecommitdiff
path: root/src/map/mob.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/map/mob.h')
-rw-r--r--src/map/mob.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/map/mob.h b/src/map/mob.h
index a3b589964..367640e07 100644
--- a/src/map/mob.h
+++ b/src/map/mob.h
@@ -143,7 +143,7 @@ struct item_drop {
};
struct item_drop_list {
int m, x, y; // coordinates
- int first_id, second_id, third_id; // id's of players with higher pickup priority
+ int first_charid, second_charid, third_charid; // charid's of players with higher pickup priority
struct item_drop* item; // linked list of drops
};